# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PagedResultsModelDashboardResponse(Model):
    """PagedResultsModelDashboardResponse.

    :param result:
    :type result: list[~smartdiagnostics_sdk.models.DashboardResponse]
    :param total:
    :type total: int
    :param total_pages:
    :type total_pages: int
    """

    _attribute_map = {
        'result': {'key': 'Result', 'type': '[DashboardResponse]'},
        'total': {'key': 'Total', 'type': 'int'},
        'total_pages': {'key': 'TotalPages', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(PagedResultsModelDashboardResponse, self).__init__(**kwargs)
        self.result = kwargs.get('result', None)
        self.total = kwargs.get('total', None)
        self.total_pages = kwargs.get('total_pages', None)
