# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CustomMarkerChild(Model):
    """CustomMarkerChild.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name:
    :type name: str
    :param show_harmonics: Required.
    :type show_harmonics: bool
    :param show_side_bands: Required.
    :type show_side_bands: bool
    :param show_peaks: Required.
    :type show_peaks: bool
    """

    _validation = {
        'id': {'required': True},
        'name': {'max_length': 5},
        'show_harmonics': {'required': True},
        'show_side_bands': {'required': True},
        'show_peaks': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'show_harmonics': {'key': 'ShowHarmonics', 'type': 'bool'},
        'show_side_bands': {'key': 'ShowSideBands', 'type': 'bool'},
        'show_peaks': {'key': 'ShowPeaks', 'type': 'bool'},
    }

    def __init__(self, *, id: str, show_harmonics: bool, show_side_bands: bool, show_peaks: bool, name: str=None, **kwargs) -> None:
        super(CustomMarkerChild, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.show_harmonics = show_harmonics
        self.show_side_bands = show_side_bands
        self.show_peaks = show_peaks
